[Numpy-svn] r4884 - trunk/numpy

numpy-svn at scipy.org numpy-svn at scipy.org
Tue Mar 18 07:56:29 EDT 2008


Author: stefan
Date: 2008-03-18 06:56:24 -0500 (Tue, 18 Mar 2008)
New Revision: 4884

Modified:
   trunk/numpy/ctypeslib.py
Log:
Ctypes loads .so/.pyd if library is not found.


Modified: trunk/numpy/ctypeslib.py
===================================================================
--- trunk/numpy/ctypeslib.py	2008-03-18 11:17:21 UTC (rev 4883)
+++ trunk/numpy/ctypeslib.py	2008-03-18 11:56:24 UTC (rev 4884)
@@ -31,9 +31,9 @@
                           "with ctypes < 1.0.1")
         if '.' not in libname:
             # Try to load library with platform-specific name, otherwise
             # default to libname.so.  Sometimes, .so files are built
             # erroneously on non-linux platforms.
-            libname_ext = ['%s.so' % libname]
+            libname_ext = ['%s.so' % libname, '%s.pyd' % libname]
             if sys.platform == 'win32':
                 libname_ext.insert(0, '%s.dll' % libname)
             elif sys.platform == 'darwin':
@@ -31,9 +31,9 @@
         if '.' not in libname:
             # Try to load library with platform-specific name, otherwise
-            # default to libname.so.  Sometimes, .so files are built
+            # default to libname.[so|pyd].  Sometimes, these files are built
             # erroneously on non-linux platforms.




More information about the Numpy-svn mailing list